@@ -1,9 +1,8 @@
 # ABSTRACT: Handle communication between a debugger and clients
 
-
 package Vim::Debug::Daemon;
 
-our $VERSION = '0.903'; # VERSION
+our $VERSION = '0.904'; # VERSION
 
 use Moose;
 use MooseX::ClassAttribute;
@@ -17,7 +16,7 @@ $| = 1;
 # global var
 my $shutdown = 0;
 
-has port => ( is => 'ro', isa => 'Int', default => 6543 );
+class_has port => ( is => 'ro', isa => 'Int', default => 6543 );
 
 class_has debuggers => (
     is      => 'rw',
@@ -84,7 +83,7 @@ sub start {
     my ($sessionId, $language, $command) = ($1, $2, $3);
 
     __PACKAGE__->debuggers->{$sessionId} = Vim::Debug->new(
-        language => $language, 
+        language => $language,
         invoke   => $command
     )->start;
 
@@ -110,7 +109,7 @@ sub stop {
 }
 
 sub translate {
-    # Translate protocol $in to native debugger cmds. 
+    # Translate protocol $in to native debugger cmds.
     $_[HEAP]{translation} = $_[HEAP]{debugger}->translate($_[ARG0]);
     $_[KERNEL]->yield("Write", @_[ARG0..$#_]);
 }
@@ -127,7 +126,7 @@ sub write {
     my $cmds = $_[HEAP]{translation};
     my $state;
 
-    if (scalar(@$cmds) == 0) { 
+    if (scalar(@$cmds) == 0) {
         $state = 'Out';
     }
     else {
@@ -149,7 +148,6 @@ sub out {
     Vim::Debug::Protocol->touch;
 }
 
-
 1;
 
 __END__
@@ -174,7 +172,7 @@ L<Vim::Debug::Manual>, first.
 
 This module implements a TCP server.  Clients will usually be an editor like
 Vim.  A debugger is spawned for each client.  The daemon manages communication
-between one or more clients and their debuggers.  
+between one or more clients and their debuggers.
 
 Internally this is implemented with POE so that it can do non blocking reads
 for debugger output.  This allows the user to send an interrupt.  This is
