@@ -3,7 +3,7 @@
 
 package Vim::Debug::Manual;
 
-our $VERSION = '0.903'; # VERSION
+our $VERSION = '0.904'; # VERSION
 
 __END__
 
@@ -27,52 +27,44 @@ later and some CPAN modules may need to be installed.  It also requires Vim
 
 =head1 How do I install VimDebug?
 
-VimDebug has a Perl component and a Vim component.  To install the Perl
-libraries use L<cpanm|https://metacpan.org/module/App::cpanminus>:
+VimDebug has a Perl component and a Vim component. The Vim component
+happens to be supplied with the Perl component.
+
+The Perl component, Vim::Debug, can be obtained from CPAN. A simple
+way to install it is to use L<cpanminus's|https://metacpan.org/module/App::cpanminus> C<cpanm>
+program. First, install C<cpanminus>:
 
-    # install cpanm
     curl -L http://cpanmin.us | perl - --sudo App::cpanminus
 
-    # install VimDebug Perl libraries
+Then, install VimDebug's Perl files:
+
     cpanm Vim::Debug
 
-Next, install the Vim component:
+To install the Vim component, execute the following program,
+which was installed with the Perl component:
 
     vimdebug-install -d ~/.vim
 
 You may want to replace C<~/.vim> by some other directory that your
-Vim recognizes as a runtimepath directory. See Vim's ":help
-'runtimepath'" for more information.
+Vim recognizes as a runtimepath directory. See Vim's C<:help
+'runtimepath'> for more information.
 
-=head1 Using VimDebug
+Finally, launch Vim and install and read the Vim help file, which
+describes how to use VimDebug:
 
-Launch Vim and open a file named with a ".pl" extension. Press <F12>
-to start the debugger. To change the default Vim key bindings, shown
-here, edit VimDebug.vim:
+    :helptags ~/.vim/doc
+    :help VimDebug
 
-    <F12>      Start the debugger
-    <Leader>s/ Start the debugger.  Prompts for command line arguments.
-    <F10>      Restart debugger. Break points are ALWAYS saved (for all dbgrs).
-    <F11>      Exit the debugger
-
-    <F6>       Next
-    <F7>       Step
-    <F8>       Continue
-
-    <Leader>b  Set break point on the current line
-    <Leader>c  Clear break point on the current line
-
-    <Leader>v  Print the value of the variable under the cursor
-    <Leader>v/ Print the value of an expression thats entered
-
-    <Leader>/  Type a command for the debugger to execute and echo the result
+Make sure that the directory where that C<doc> directory resides is in
+your Vim runtimepath, else Vim won't find its help information even if
+it manages to build the help index.
 
 =head1 Improving VimDebug
 
 VimDebug is on github: https://github.com/kablamo/VimDebug.git
 
 To do development work on VimDebug, clone its git repo and read
-./documentation/DEVELOPER.HOWOTO.
+./documentation/DEVELOPER.
 
 In principle, the VimDebug code can be extended to handle other
 debuggers, like the one for Ruby or Python, but that remains to be
