@@ -1,19 +1,12 @@
 # ABSTRACT: Everything needed for the VimDebug network protocol
 
-
 package Vim::Debug::Protocol;
 
-our $VERSION = '0.903'; # VERSION
+our $VERSION = '0.904'; # VERSION
 
 use Moose;
 use MooseX::ClassAttribute;
 
-
-class_has compilerError => ( is => 'ro', isa => 'Str', default => 'compiler error' );
-class_has runtimeError  => ( is => 'ro', isa => 'Str', default => 'runtime error' );
-class_has dbgrReady     => ( is => 'ro', isa => 'Str', default => 'debugger ready' );
-class_has appExited => ( is => 'ro', isa => 'Str', default => 'application exited' );
-
 has status     => ( is => 'rw', isa => 'Str' );
 has line       => ( is => 'rw', isa => 'Int' );
 has file       => ( is => 'rw', isa => 'Str' );
@@ -21,50 +14,47 @@ has value      => ( is => 'rw', isa => 'Str' );
 has output     => ( is => 'rw', isa => 'Str' );
 
 # protocol constants
-# $self->eor is end of record.  $self->eom is end of message
-class_has _eor        => ( is => 'ro', isa => 'Str', default => '-vimdebug.eor-' );
-class_has _eom        => ( is => 'ro', isa => 'Str', default => "\r\nvimdebug.eom" );
-class_has _badCmd     => ( is => 'ro', isa => 'Str', default => 'bad command' );
-class_has _connect    => ( is => 'ro', isa => 'Str', default => 'CONNECT' );
-class_has _disconnect => ( is => 'ro', isa => 'Str', default => 'DISCONNECT' );
-
-
+# "eor": end of record; "eom": end of message.
+class_has k_compilerError => ( is => 'ro', isa => 'Str', default => 'compiler error' );
+class_has k_runtimeError  => ( is => 'ro', isa => 'Str', default => 'runtime error' );
+class_has k_dbgrReady     => ( is => 'ro', isa => 'Str', default => 'debugger ready' );
+class_has k_appExited     => ( is => 'ro', isa => 'Str', default => 'application exited' );
+class_has k_eor           => ( is => 'ro', isa => 'Str', default => ' {-VDEOR-} ' );
+class_has k_eom           => ( is => 'ro', isa => 'Str', default => " {-VDEOM-}" );
+class_has k_badCmd        => ( is => 'ro', isa => 'Str', default => 'bad command' );
+class_has k_connect       => ( is => 'ro', isa => 'Str', default => 'CONNECT' );
+class_has k_disconnect    => ( is => 'ro', isa => 'Str', default => 'DISCONNECT' );
+class_has k_doneFile      => ( is => 'ro', isa => 'Str', default => '.vdd.done' );
 
 sub connect {
     my $class = shift or die;
     my $sessionId = shift or die;
-    return $class->response( status => _connect(), value => $sessionId );
+    return $class->response( status => k_connect(), value => $sessionId );
 }
 
-
 sub disconnect {
     my $class = shift or die;
-    return $class->response( status => _disconnect() );
+    return $class->response( status => k_disconnect() );
 }
 
-
 sub response {
     my $class = shift;
     my $self  = $class->new(@_);
     my $response;
     foreach my $attr (qw/status line file value output/) {
         $response .= $self->$attr if defined $self->$attr;
-        $response .= $self->_eor unless $attr eq 'output';
+        $response .= $self->k_eor unless $attr eq 'output';
     }
-    $response .= $self->_eom;
+    $response .= $self->k_eom;
     return $response;
 }
 
-
 sub touch {
-    my $DONE_FILE = ".vdd.done";
-    open(FILE, ">", $DONE_FILE);
+    open FILE, ">", Vim::Debug::Protocol->k_doneFile;
     print FILE "\n";
-    close(FILE);
+    close FILE;
 }
 
-
-
 1;
 
 __END__
@@ -100,6 +90,30 @@ This module implements the network protocol between Vim and the
 Vim::Debug::Daemon.  It worries about end of field and end of message strings
 and all that sort of formatting.
 
+=head1 FUNCTIONS
+
+=head2 connect($sessionId)
+
+Returns formatted string that is used to reply to a client who just connected
+to Vim::Debug::Daemon.
+
+=head2 disconnect()
+
+Returns formatted string that is used to tell a client to disconnect from
+Vim::Debug::Daemon.
+
+=head2 response()
+
+Any of the class attributes can be passed to this method.
+
+Returns formatted string that is used to tell respond to a client that is
+talking to the Vim::Debug::Daemon.
+
+=head2 touch()
+
+This method needs to be called after send a message to Vim.  It creates a
+file.
+
 =head1 COMMUNICATION PROTOCOL
 
 All messages passed between the client (vim) and the daemon (vdd) consist of a
@@ -128,7 +142,7 @@ All messages to the server have the following format:
     Parameter 2
     End Of Record
     ..
-    Parameter n 
+    Parameter n
     End Of Message
 
 After every message, the daemon also touches a file.  Which is kind of crazy
@@ -140,7 +154,7 @@ nonblocking reads on the sockets.
 When you connect to the Vim::Debug Daemon (vdd), it will send you a message
 that looks like this:
 
-    $CONNECT . $EOR . $EOR . $EOR . $SESSION_ID . $EOR . $EOM 
+    $CONNECT . $EOR . $EOR . $EOR . $SESSION_ID . $EOR . $EOM
 
 You should respond with a message that looks like
 
@@ -161,17 +175,17 @@ And then exit.
 =head1 POE STATE DIAGRAM
 
     ClientConnected
-        
+
             ---> Stop
            |
     ClientInput ----------> Start
-      |                      |   
+      |                      |
       |                      |   __
       v                      v  v  |
      Translate --> Write --> Read  |
                    |   ^     |  |  |
                    |   |_____|  |__|
-                   |   
+                   |
                    v
                   Out
 
@@ -189,30 +203,6 @@ These values all indicate the current state of the debugger.
 
 =head2 output()
 
-=head1 FUNCTIONS
-
-=head2 connect($sessionId)
-
-Returns formatted string that is used to reply to a client who just connected
-to Vim::Debug::Daemon.
-
-=head2 disconnect()
-
-Returns formatted string that is used to tell a client to disconnect from
-Vim::Debug::Daemon.
-
-=head2 response()
-
-Any of the class attributes can be passed to this method.
-
-Returns formatted string that is used to tell respond to a client that is
-talking to the Vim::Debug::Daemon.  
-
-=head2 touch()
-
-This method needs to be called after send a message to Vim.  It creates a
-file.
-
 =head1 SEE ALSO
 
 L<Vim::Debug::Daemon>
