@@ -1,47 +1,45 @@
-# ABSTRACT: Vim::Debug Client
+# ABSTRACT: A Vim::Debug client, for testing.
 
 =head1 SYNOPSIS
 
-   use Vim::Debug::Client;
-   Vim::Debug::Client->connect();
+    use Vim::Debug::Client;
+    Vim::Debug::Client->connect();
 
 =head1 DESCRIPTION
 
-This module implements a Vim::Debug client.  The client communicates with the
-Vim::Debug::Daemon.  Its probably only useful for testing.
+This module implements a Vim::Debug client. The client communicates
+with the Vim::Debug::Daemon.  It's probably only useful for testing.
 
 =cut
-
 package Vim::Debug::Client;
-
-use strict;
+use Moose;
 use warnings;
-use feature qw(say);
-use base qw(Class::Accessor::Fast);
+
+# VERSION
 
 use Net::Telnet;
-use Vim::Debug::Client::Response;
-
-__PACKAGE__->mk_accessors( qw(language dbgrCmd telnet sessionId) );
-
+use Vim::Debug::Protocol;
 
 # constants
-$Vim::Debug::Client::VERSION = "0.00";
+$Vim::Debug::Client::VERSION = "0.1";
 $| = 1;
 
 # protocol constants
-my $EOR            = '[vimdebug.eor]';       # end of record
-my $EOR_REGEX      = qr/\[vimdebug.eor\]/;
-my $EOR_LENGTH     = length($EOR);
-my $EOM            = "\r\nvimdebug.eom\n";   # end of message
-my $EOM_REGEX      = '/\nvimdebug.eom\n/';
-my $BAD_CMD        = "bad command";
-my $CONNECT        = "CONNECT";
-my $DISCONNECT     = "DISCONNECT";
+my $EOM       = Vim::Debug::Protocol->k_eom . "\n";
+my $EOM_REGEX = "/\Q$EOM\E/";
 
 # connection constants
-my $DONE_FILE = ".vdd.done";
+has language  => ( is => 'ro', isa => 'Str' );
+has dbgrCmd   => ( is => 'ro', isa => 'Str' );
+has telnet    => ( is => 'rw', isa => 'Net::Telnet' );
+has sessionId => ( is => 'rw', isa => 'Int' );
 
+has _protocol => ( 
+    is          => 'ro', 
+    isa         => 'Vim::Debug::Protocol', 
+    default     => sub { Vim::Debug::Protocol->new },
+    handles     => [qw/k_eor k_eom k_connect k_disconnect/],
+);
 
 sub connect {
     my $self = shift or die;
@@ -49,10 +47,10 @@ sub connect {
     my $telnet = Net::Telnet->new(
         Timeout    => 10,
         Prompt     => $EOM_REGEX,
-        Rs         => $EOR, # input  record separator -- not a regex
+        Rs         => $self->k_eor, # input  record separator -- not a regex
         Ors        => "\n", # output record separator -- not a regex
         Telnetmode => 0,
-        Port       => 6543,
+        Port       => Vim::Debug::Daemon->port,
     );
     $self->telnet($telnet);
 
@@ -67,7 +65,7 @@ sub connect {
     }
 
     my ($output, $eom) = $telnet->waitfor($EOM_REGEX);
-    my @parts = split($EOR_REGEX, $output);
+    my @parts = split $self->k_eor, $output;
 
     $self->sessionId($parts[-1]);
 
@@ -106,9 +104,9 @@ sub jfdi {
 sub buildResponse {
     my ( $self, @response) = @_;
 
-    @response = map { substr($_, 0, -$EOR_LENGTH) } @response;
+    @response = map { substr($_, 0, -length($self->k_eor)) } @response;
 
-    my $response = Vim::Debug::Client::Response->new({
+    my $response = Vim::Debug::Protocol->new({
         status => $response[0],
         line   => $response[1],
         file   => $response[2],
@@ -134,6 +132,4 @@ sub quit     {
     return 1;
 }
 
-
-
 1;
